| Title: | Easily Extract Data from 'StatsWales' |
|---|---|
| Description: | Download data from 'StatsWales' into R. |
| Authors: | Jamie Ralph [aut, cre] |
| Maintainer: | Jamie Ralph <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.3.0 |
| Built: | 2026-05-10 07:13:29 UTC |
| Source: | https://github.com/jamie-ralph/statswalesr |
statswales_get_dataset returns a dataframe from
StatsWales using a dataset id.
statswales_get_dataset(id)statswales_get_dataset(id)
id |
A dataset id. Must be a single string. |
If the dataset id is valid, the function will return the requested dataset in a dataframe. If the id is not valid, the function will return NULL.
data <- statswales_get_dataset("LGFS0021")data <- statswales_get_dataset("LGFS0021")